==> protector-3.1.zip: xoops_trust_path/modules/protector/language/portuguesebr/modinfo.php <==
<?php 

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) ) $mydirname = 'protector' ;
$constpref = '_MI_' . strtoupper( $mydirname ) ;

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( $constpref.'_LOADED' ) ) {



// Appended by Xoops Language Checker -GIJOE- in 2007-07-30 16:31:32
define($constpref.'_BANIP_TIME0','Banned IP suspension time (sec)');
define($constpref.'_OPT_BIPTIME0','Ban the IP (moratorium)');
define($constpref.'_DOSOPT_BIPTIME0','Ban the IP (moratorium)');

// Appended by Xoops Language Checker -GIJOE- in 2007-03-29 03:36:14
define($constpref.'_ADMENU_MYBLOCKSADMIN','Permissions');

define( $constpref.'_LOADED' , 1 ) ;

// The name of this module
define($constpref."_NAME","Xoops Protector");

// A brief description of this module
define($constpref."_DESC","Mdulo para proteo do XOOPS contra ataques mal-intencionados, em especial: ataques DoS, SQL Injection e contaminaes por varivel.");


// Menu
define($constpref."_ADMININDEX","Central de proteo");
define($constpref."_ADVISORY","Guia de segurana");
define($constpref."_PREFIXMANAGER","Gerenciador de PREFIXO");

// Configs
define($constpref.'_GLOBAL_DISBL',"Interrupo temporria de funcionamento");
define($constpref.'_GLOBAL_DISBLDSC',"Suspende temporariamente o funcionamento de todas as protees.<br />Aps resolver os problemas, no se esquea de desativ-la.");
define($constpref.'_RELIABLE_IPS',"IPs confiveis");
define($constpref.'_RELIABLE_IPSDSC',"Indique os endereos IP que no passaro por examinao para ataques DoS, separados por |. ^ para o invlido, e  $ para o final do string.");
define($constpref.'_LOG_LEVEL',"Nvel de logging");
define($constpref.'_LOG_LEVELDSC',"");

define($constpref.'_LOGLEVEL0',"No gerar log");
define($constpref.'_LOGLEVEL15',"Gerar log apenas de elementos de alto risco");
define($constpref.'_LOGLEVEL63',"No gerar log de elementos de baixo risco");
define($constpref.'_LOGLEVEL255',"Gerar log de todos os elementos");

define($constpref.'_HIJACK_TOPBIT',"Proteo de IP bits contra renovao de sesso");
define($constpref.'_HIJACK_TOPBITDSC',"Preveno  session hijack:<br />O padro  32(bit) e protege de todos os bits.<br />Caso use Proxy ou seu endereo IP mude a cada acesso, defina o intervalo de bits mais longo possvel  invariao.<br />Ex.: Se houver possibilidade de variao dentro de 192.168.0.0~192.168.0.255, defina esta opo como 24(bit).");
define($constpref.'_HIJACK_DENYGP',"Grupos proibidos de mudana de IP");
define($constpref.'_HIJACK_DENYGPDSC',"Preveno  session hijack:<br />Escolha os grupos cujos usurios proibidos de alterao de endereo IP durante uma sesso.<br />(Recomendado: \"Administradores\")");
define($constpref.'_SAN_NULLBYTE',"Substituio de caracteres nulos por espaos");
define($constpref.'_SAN_NULLBYTEDSC',"O caracter \"\\0\" fatal  usado freqentemente em ataques maliciosos.<br />Sempre que detectado, ele ser substituio por um espao.<br />(Recomendado)");
define($constpref.'_DIE_NULLBYTE',"Encerramento forado de sesso em caso de deteco de caracteres nulos");
define($constpref.'_DIE_NULLBYTEDSC',"O caracter \"\\0\" fatal  usado frequentemente em ataques maliciosos.<br />(Recomendado)");
define($constpref.'_DIE_BADEXT',"Encerramento forado de sesso em caso de uploads com extenses proibidas");
define($constpref.'_DIE_BADEXTDSC',"Caso houver uploads de arquivos com extenses como .php ou outros arquivos executveis no servidor, a sesso ser apagada.<br />(No recomendado se voc for usurio de B-Wiki ou PukiWikiMod e anexar cdigos-fonte em PHP.)");
define($constpref.'_CONTAMI_ACTION',"Soluo em caso de deteco de contaminaes por varivel");
define($constpref.'_CONTAMI_ACTIONDS',"Escolha o tipo de soluo quando uma tentativa de alterao das globais de sistema do XOOPS for detectada.<br />(Padro: \"Encerramento forado de sesso\")");
define($constpref.'_ISOCOM_ACTION',"Soluo em caso de deteco de comentrios isolados");
define($constpref.'_ISOCOM_ACTIONDSC',"Preveno  SQL injection:<br />Escolha o tipo de soluo quando um comentrio isolado /* for detectado sem seu par */.<br />Processo de sanitizao: */  inserido no final.<br />(Recomendado: \"Sanitizao\")");
define($constpref.'_UNION_ACTION',"Soluo em caso de deteco de UNION");
define($constpref.'_UNION_ACTIONDSC',"Preveno  SQL injection:<br />Escolha o tipo de soluo quando uma sintaxe UNION do SQL for detectada.<br />Processo de sanitizao: UNION  alterado para uni-on.<br />(Recomendado: \"Sanitizao\")");
define($constpref.'_ID_INTVAL',"Converso forada de varivel ID");
define($constpref.'_ID_INTVALDSC',"Fora valores numricos e variveis com nomes terminados em \"id\".  eficaz, principalmente, com mdulos derivados do myLinks. Protege tambm de alguns XSS e SQL injection. Entretanto, pode entrar em conflito com alguns mdulos.");
define($constpref.'_FILE_DOTDOT',"Proibido de DirectoryTraversal");
define($constpref.'_FILE_DOTDOTDSC',"Numa tentativa de DirectoryTraversal, o pedido  analisado, e a pattern \"..\"  removida.");

define($constpref.'_BF_COUNT',"Preveno  Brute Force");
define($constpref.'_BF_COUNTDSC',"Contra round-robin. Se, dentro de 10 minutos, o n de tentativas de login incorreto definido nesta opo for excedido, o IP ser banido.");

define($constpref.'_DOS_SKIPMODS',"Mdulos excludos de observao de alvo de DoS");
define($constpref.'_DOS_SKIPMODSDSC',"Defina os mdulos que quiser excluir, separados por |. Ative para mdulos de chat e similares.");

define($constpref.'_DOS_EXPIRE',"Tempo de observao para ataques DoS (em segundos)");
define($constpref.'_DOS_EXPIREDSC',"Tempo de observao para acompanhar a frequncia dos acessos de DoS e crawlers maliciosos.");

define($constpref.'_DOS_F5COUNT',"N de vezes para ser reconhecido como ataque F5");
define($constpref.'_DOS_F5COUNTDSC',"Defesa contra ataques DoS:<br />Se houver muitos acessos  uma mesma URL dentro do tempo de observao definido acima e do n de vezes definidas nesta opo, ser reconhecido como um ataque.");
define($constpref.'_DOS_F5ACTION',"Medidas contra ataques F5");

define($constpref.'_DOS_CRCOUNT',"N de vezes para ser reconhecido como um crawler malicioso");
define($constpref.'_DOS_CRCOUNTDSC',"Preveno  crawlers maliciosos (como bots catadores de e-mails):<br />Se forem realizadas buscas dentro do site dentro do tempo de observao definido acima e do n de vezes definidas nesta opo, ser reconhecido como um crawler malicioso.");
define($constpref.'_DOS_CRACTION',"Soluo para crawlers maliciosos");

define($constpref.'_DOS_CRSAFE',"User-Agent permitidos");
define($constpref.'_DOS_CRSAFEDSC',"Descreva incondicionalmente o nome dos provveis crawlers com uma perl regex pattern.<br />Ex.: /(msnbot|Googlebot|Yahoo! Slurp)/i");

define($constpref.'_OPT_NONE',"Nenhuma (apenas gerar log)");
define($constpref.'_OPT_SAN',"Sanitizao");
define($constpref.'_OPT_EXIT',"Encerramento forado de sesso");
define($constpref.'_OPT_BIP',"Banimento por IP");

define($constpref.'_DOSOPT_NONE',"Nenhuma (apenas gerar log)");
define($constpref.'_DOSOPT_SLEEP',"Sleep");
define($constpref.'_DOSOPT_EXIT',"exit");
define($constpref.'_DOSOPT_BIP',"Adicionar  lista de IPs banidos");
define($constpref.'_DOSOPT_HTA',"Registrar DENY atravs de .htaccess (experimental)");

define($constpref.'_BIP_EXCEPT',"Grupos livres de banimento por IP");
define($constpref.'_BIP_EXCEPTDSC',"Mesmo quando a condio for satisfeita, os usurios dos grupos indicados nesta opo np sero adicionados  lista de IPs banidos. Entretanto, se estes usurios no fizerem login, o efeito desta opo ser anulado. TENHA CUIDADO!<br />(Recomendado: \"Administradores\")");

define($constpref.'_DISABLES',"Desativar opes inseguras");


define($constpref.'_BIGUMBRELLA','ativar anti-XSS (BigUmbrella)');
define($constpref.'_BIGUMBRELLADSC','Isto protege seu site contra ataques por vulnerabilidades via XSS. Mas no  100% garantido');

define($constpref.'_SPAMURI4U','anti-SPAM: URLs for normal users');
define($constpref.'_SPAMURI4UDSC','If this number of URLs are found in POST data from users other than admin, the POST is considered as SPAM. 0 means disabling this feature.');
define($constpref.'_SPAMURI4G','anti-SPAM: URLs for guests');
define($constpref.'_SPAMURI4GDSC','If this number of URLs are found in POST data from guests, the POST is considered as SPAM. 0 means disabling this feature.');
}
?>

==> protector-3.2.zip: xoops_trust_path/modules/protector/language/portuguesebr/modinfo.php <==
<?php 

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) ) $mydirname = 'protector' ;
$constpref = '_MI_' . strtoupper( $mydirname ) ;

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( $constpref.'_LOADED' ) ) {




// Appended by Xoops Language Checker -GIJOE- in 2008-11-21 04:44:30
define($constpref.'_DEFAULT_LANG','Default language');
define($constpref.'_DEFAULT_LANGDSC','Specify the language set to display messages before processing common.php');
define($constpref.'_BWLIMIT_COUNT','Bandwidth limitation');
define($constpref.'_BWLIMIT_COUNTDSC','Specify the max access to mainfile.php during watching time. This value should be 0 for normal environments which have enough CPU bandwidth. The number fewer than 10 will be ignored.');

// Appended by Xoops Language Checker -GIJOE- in 2007-07-30 16:31:32
define($constpref.'_BANIP_TIME0','Banned IP suspension time (sec)');
define($constpref.'_OPT_BIPTIME0','Ban the IP (moratorium)');
define($constpref.'_DOSOPT_BIPTIME0','Ban the IP (moratorium)');

// Appended by Xoops Language Checker -GIJOE- in 2007-03-29 03:36:14
define($constpref.'_ADMENU_MYBLOCKSADMIN','Permissions');

define( $constpref.'_LOADED' , 1 ) ;

// The name of this module
define($constpref."_NAME","Xoops Protector");

// A brief description of this module
define($constpref."_DESC","Mdulo para proteo do XOOPS contra ataques mal-intencionados, em especial: ataques DoS, SQL Injection e contaminaes por varivel.");


// Menu
define($constpref."_ADMININDEX","Central de proteo");
define($constpref."_ADVISORY","Guia de segurana");
define($constpref."_PREFIXMANAGER","Gerenciador de PREFIXO");

// Configs
define($constpref.'_GLOBAL_DISBL',"Interrupo temporria de funcionamento");
define($constpref.'_GLOBAL_DISBLDSC',"Suspende temporariamente o funcionamento de todas as protees.<br />Aps resolver os problemas, no se esquea de desativ-la.");
define($constpref.'_RELIABLE_IPS',"IPs confiveis");
define($constpref.'_RELIABLE_IPSDSC',"Indique os endereos IP que no passaro por examinao para ataques DoS, separados por |. ^ para o invlido, e  $ para o final do string.");
define($constpref.'_LOG_LEVEL',"Nvel de logging");
define($constpref.'_LOG_LEVELDSC',"");

define($constpref.'_LOGLEVEL0',"No gerar log");
define($constpref.'_LOGLEVEL15',"Gerar log apenas de elementos de alto risco");
define($constpref.'_LOGLEVEL63',"No gerar log de elementos de baixo risco");
define($constpref.'_LOGLEVEL255',"Gerar log de todos os elementos");

define($constpref.'_HIJACK_TOPBIT',"Proteo de IP bits contra renovao de sesso");
define($constpref.'_HIJACK_TOPBITDSC',"Preveno  session hijack:<br />O padro  32(bit) e protege de todos os bits.<br />Caso use Proxy ou seu endereo IP mude a cada acesso, defina o intervalo de bits mais longo possvel  invariao.<br />Ex.: Se houver possibilidade de variao dentro de 192.168.0.0~192.168.0.255, defina esta opo como 24(bit).");
define($constpref.'_HIJACK_DENYGP',"Grupos proibidos de mudana de IP");
define($constpref.'_HIJACK_DENYGPDSC',"Preveno  session hijack:<br />Escolha os grupos cujos usurios proibidos de alterao de endereo IP durante uma sesso.<br />(Recomendado: \"Administradores\")");
define($constpref.'_SAN_NULLBYTE',"Substituio de caracteres nulos por espaos");
define($constpref.'_SAN_NULLBYTEDSC',"O caracter \"\\0\" fatal  usado freqentemente em ataques maliciosos.<br />Sempre que detectado, ele ser substituio por um espao.<br />(Recomendado)");
define($constpref.'_DIE_NULLBYTE',"Encerramento forado de sesso em caso de deteco de caracteres nulos");
define($constpref.'_DIE_NULLBYTEDSC',"O caracter \"\\0\" fatal  usado frequentemente em ataques maliciosos.<br />(Recomendado)");
define($constpref.'_DIE_BADEXT',"Encerramento forado de sesso em caso de uploads com extenses proibidas");
define($constpref.'_DIE_BADEXTDSC',"Caso houver uploads de arquivos com extenses como .php ou outros arquivos executveis no servidor, a sesso ser apagada.<br />(No recomendado se voc for usurio de B-Wiki ou PukiWikiMod e anexar cdigos-fonte em PHP.)");
define($constpref.'_CONTAMI_ACTION',"Soluo em caso de deteco de contaminaes por varivel");
define($constpref.'_CONTAMI_ACTIONDS',"Escolha o tipo de soluo quando uma tentativa de alterao das globais de sistema do XOOPS for detectada.<br />(Padro: \"Encerramento forado de sesso\")");
define($constpref.'_ISOCOM_ACTION',"Soluo em caso de deteco de comentrios isolados");
define($constpref.'_ISOCOM_ACTIONDSC',"Preveno  SQL injection:<br />Escolha o tipo de soluo quando um comentrio isolado /* for detectado sem seu par */.<br />Processo de sanitizao: */  inserido no final.<br />(Recomendado: \"Sanitizao\")");
define($constpref.'_UNION_ACTION',"Soluo em caso de deteco de UNION");
define($constpref.'_UNION_ACTIONDSC',"Preveno  SQL injection:<br />Escolha o tipo de soluo quando uma sintaxe UNION do SQL for detectada.<br />Processo de sanitizao: UNION  alterado para uni-on.<br />(Recomendado: \"Sanitizao\")");
define($constpref.'_ID_INTVAL',"Converso forada de varivel ID");
define($constpref.'_ID_INTVALDSC',"Fora valores numricos e variveis com nomes terminados em \"id\".  eficaz, principalmente, com mdulos derivados do myLinks. Protege tambm de alguns XSS e SQL injection. Entretanto, pode entrar em conflito com alguns mdulos.");
define($constpref.'_FILE_DOTDOT',"Proibido de DirectoryTraversal");
define($constpref.'_FILE_DOTDOTDSC',"Numa tentativa de DirectoryTraversal, o pedido  analisado, e a pattern \"..\"  removida.");

define($constpref.'_BF_COUNT',"Preveno  Brute Force");
define($constpref.'_BF_COUNTDSC',"Contra round-robin. Se, dentro de 10 minutos, o n de tentativas de login incorreto definido nesta opo for excedido, o IP ser banido.");

define($constpref.'_DOS_SKIPMODS',"Mdulos excludos de observao de alvo de DoS");
define($constpref.'_DOS_SKIPMODSDSC',"Defina os mdulos que quiser excluir, separados por |. Ative para mdulos de chat e similares.");

define($constpref.'_DOS_EXPIRE',"Tempo de observao para ataques DoS (em segundos)");
define($constpref.'_DOS_EXPIREDSC',"Tempo de observao para acompanhar a frequncia dos acessos de DoS e crawlers maliciosos.");

define($constpref.'_DOS_F5COUNT',"N de vezes para ser reconhecido como ataque F5");
define($constpref.'_DOS_F5COUNTDSC',"Defesa contra ataques DoS:<br />Se houver muitos acessos  uma mesma URL dentro do tempo de observao definido acima e do n de vezes definidas nesta opo, ser reconhecido como um ataque.");
define($constpref.'_DOS_F5ACTION',"Medidas contra ataques F5");

define($constpref.'_DOS_CRCOUNT',"N de vezes para ser reconhecido como um crawler malicioso");
define($constpref.'_DOS_CRCOUNTDSC',"Preveno  crawlers maliciosos (como bots catadores de e-mails):<br />Se forem realizadas buscas dentro do site dentro do tempo de observao definido acima e do n de vezes definidas nesta opo, ser reconhecido como um crawler malicioso.");
define($constpref.'_DOS_CRACTION',"Soluo para crawlers maliciosos");

define($constpref.'_DOS_CRSAFE',"User-Agent permitidos");
define($constpref.'_DOS_CRSAFEDSC',"Descreva incondicionalmente o nome dos provveis crawlers com uma perl regex pattern.<br />Ex.: /(msnbot|Googlebot|Yahoo! Slurp)/i");

define($constpref.'_OPT_NONE',"Nenhuma (apenas gerar log)");
define($constpref.'_OPT_SAN',"Sanitizao");
define($constpref.'_OPT_EXIT',"Encerramento forado de sesso");
define($constpref.'_OPT_BIP',"Banimento por IP");

define($constpref.'_DOSOPT_NONE',"Nenhuma (apenas gerar log)");
define($constpref.'_DOSOPT_SLEEP',"Sleep");
define($constpref.'_DOSOPT_EXIT',"exit");
define($constpref.'_DOSOPT_BIP',"Adicionar  lista de IPs banidos");
define($constpref.'_DOSOPT_HTA',"Registrar DENY atravs de .htaccess (experimental)");

define($constpref.'_BIP_EXCEPT',"Grupos livres de banimento por IP");
define($constpref.'_BIP_EXCEPTDSC',"Mesmo quando a condio for satisfeita, os usurios dos grupos indicados nesta opo np sero adicionados  lista de IPs banidos. Entretanto, se estes usurios no fizerem login, o efeito desta opo ser anulado. TENHA CUIDADO!<br />(Recomendado: \"Administradores\")");

define($constpref.'_DISABLES',"Desativar opes inseguras");


define($constpref.'_BIGUMBRELLA','ativar anti-XSS (BigUmbrella)');
define($constpref.'_BIGUMBRELLADSC','Isto protege seu site contra ataques por vulnerabilidades via XSS. Mas no  100% garantido');

define($constpref.'_SPAMURI4U','anti-SPAM: URLs for normal users');
define($constpref.'_SPAMURI4UDSC','If this number of URLs are found in POST data from users other than admin, the POST is considered as SPAM. 0 means disabling this feature.');
define($constpref.'_SPAMURI4G','anti-SPAM: URLs for guests');
define($constpref.'_SPAMURI4GDSC','If this number of URLs are found in POST data from guests, the POST is considered as SPAM. 0 means disabling this feature.');
}
?>
